@@ -41,7 +41,7 @@ def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,documen
     """
     jsonObject = GetJsonFromFile(document_to_predict_jsonPath);
     document = ConvertJsonToDocumentsObjects(jsonObject)[0]
-    _, df, _ , _ = make_info(document)
+    _, df, _ = make_info(document)
 
     assert len(y_pred) == df.shape[0]
 
